@@ -26,6 +26,7 @@
 #include "ianjuta-editor-line-mode.h"
 #include "ianjuta-editor-search.h"
 #include "ianjuta-editor-selection.h"
+#include "ianjuta-editor-tip.h"
 #include "ianjuta-editor-view.h"
 #include "ianjuta-editor-zoom.h"
 #include "ianjuta-environment.h"
@@ -47,8 +48,10 @@
 #include "ianjuta-plugin-factory.h"
 #include "ianjuta-preferences.h"
 #include "ianjuta-print.h"
+#include "ianjuta-project.h"
 #include "ianjuta-project-backend.h"
 #include "ianjuta-project-manager.h"
+#include "ianjuta-provider.h"
 #include "ianjuta-stream.h"
 #include "ianjuta-stream-loader.h"
 #include "ianjuta-stream-savable.h"
